@@ -1,7 +1,7 @@
 package Data::Format::Pretty::Console;
 
-our $DATE = '2015-10-20'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $DATE = '2016-03-11'; # DATE
+our $VERSION = '0.36'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,9 +12,9 @@ use Log::Any::IfLOG '$log';
 use Scalar::Util qw(blessed);
 use Text::ANSITable;
 use YAML::Any;
-use JSON;
+use JSON::MaybeXS;
 
-my $json = JSON->new->allow_nonref;
+my $json = JSON::MaybeXS->new->allow_nonref;
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -485,7 +485,7 @@ Data::Format::Pretty::Console - Pretty-print data structure for console output
 
 =head1 VERSION
 
-This document describes version 0.35 of Data::Format::Pretty::Console (from Perl distribution Data-Format-Pretty-Console), released on 2015-10-20.
+This document describes version 0.36 of Data::Format::Pretty::Console (from Perl distribution Data-Format-Pretty-Console), released on 2016-03-11.
 
 =head1 SYNOPSIS
 
@@ -695,12 +695,6 @@ To override terminal width detection.
 
 =back
 
-=head1 SEE ALSO
-
-Modules used for formatting: L<Text::ANSITable>, L<YAML>.
-
-L<Data::Format::Pretty>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Format-Pretty-Console>.
@@ -717,13 +711,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+Modules used for formatting: L<Text::ANSITable>, L<YAML>.
+
+L<Data::Format::Pretty>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
